==> haskell-http-client-tls-0.2.2-21-armv7h.pkg.tar.xz: usr/share/haskell/haskell-http-client-tls/register.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: http-client-tls
version: 0.2.2
id: http-client-tls-0.2.2-d9f6e9a017b37d355b493b30b600aa44
key: httpc_9pq8mBe518R0tOVwSMaV7a
license: MIT
maintainer: michael@snoyman.com
homepage: https://github.com/snoyberg/http-client
synopsis: http-client backend using the connection package and tls library
description:
    Intended for use by higher-level libraries, such as http-conduit.
category: Network
author: Michael Snoyman
exposed: True
exposed-modules:
    Network.HTTP.Client.TLS
trusted: False
import-dirs: /usr/lib/ghc-7.10.3/site-local/http-client-tls-0.2.2
library-dirs: /usr/lib/ghc-7.10.3/site-local/http-client-tls-0.2.2
data-dir: /usr/share/arm-linux-ghc-7.10.3/http-client-tls-0.2.2
hs-libraries: HShttp-client-tls-0.2.2-9pq8mBe518R0tOVwSMaV7a
depends:
    base-4.8.2.0-2f1f71a7fcf013cd47fd21f489064f9a
    bytestring-0.10.6.0-3b51e35daa3fe2a56ecd3687fb389cdc
    connection-0.2.5-cec1287c35c167d5820c23cf4d477cb7
    data-default-class-0.0.1-fcbab95490d730dd2489b628499587cd
    http-client-0.4.26.2-c2eaefc770ba5c6095150732f28d8ca8
    network-2.6.2.1-602ee4a12c5a174f6683a75303a065d3
    tls-1.3.4-c263a34393f014f88bd2eb81ef38f476
haddock-interfaces: /usr/share/doc/haskell-http-client-tls/html/http-client-tls.haddock
haddock-html: /usr/share/doc/haskell-http-client-tls/html
' | '/usr/bin/ghc-pkg' 'update' '-' '--global' '--no-user-package-db' "$@"

==> haskell-http-client-tls-0.2.2-25-armv7h.pkg.tar.xz: usr/share/haskell/haskell-http-client-tls/register.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: http-client-tls
version: 0.2.2
id: http-client-tls-0.2.2-93ce76b7de22e6ffcead8c1322c57414
key: httpc_0QdRoE1HP5g70eUpDULxMr
license: MIT
maintainer: michael@snoyman.com
homepage: https://github.com/snoyberg/http-client
synopsis: http-client backend using the connection package and tls library
description:
    Intended for use by higher-level libraries, such as http-conduit.
category: Network
author: Michael Snoyman
exposed: True
exposed-modules:
    Network.HTTP.Client.TLS
trusted: False
import-dirs: /usr/lib/ghc-7.10.3/site-local/http-client-tls-0.2.2
library-dirs: /usr/lib/ghc-7.10.3/site-local/http-client-tls-0.2.2
data-dir: /usr/share/arm-linux-ghc-7.10.3/http-client-tls-0.2.2
hs-libraries: HShttp-client-tls-0.2.2-0QdRoE1HP5g70eUpDULxMr
depends:
    base-4.8.2.0-2f1f71a7fcf013cd47fd21f489064f9a
    bytestring-0.10.6.0-3b51e35daa3fe2a56ecd3687fb389cdc
    connection-0.2.5-c0467ebf80f5888b80e1b38cbfa6eb3e
    data-default-class-0.0.1-fcbab95490d730dd2489b628499587cd
    http-client-0.4.27-6347f4775f754bcb55a202aff6332b65
    network-2.6.2.1-602ee4a12c5a174f6683a75303a065d3
    tls-1.3.4-b0c94e6e03e531c943403f31041ada91
haddock-interfaces: /usr/share/doc/haskell-http-client-tls/html/http-client-tls.haddock
haddock-html: /usr/share/doc/haskell-http-client-tls/html
' | '/usr/bin/ghc-pkg' 'update' '-' '--global' '--no-user-package-db' "$@"
